Package: MFSIS
Type: Package
Title: Model-Free Sure Independent Screening Procedures
Version: 0.3.1
Date: 2026-05-12
Authors@R: c(
              person("Xuewei", "Cheng", role = c("aut","cre"), email = "xwcheng@hunnu.edu.cn"),
              person("Hong", "Wang", role = c("aut"), email = "wh@csu.edu.cn"),
              person("Liping", "Zhu", role = c("aut"), email = "zhu.liping@ruc.edu.cn"),
              person("Wei", "Zhong", role = c("aut"), email = "wzhong@xmu.edu.cn"),
              person("Hanpu", "Zhou", role = c("aut"), email = "zhouhanpu@csu.edu.cn")
              )
Author: Xuewei Cheng [aut, cre],
  Hong Wang [aut],
  Liping Zhu [aut],
  Wei Zhong [aut],
  Hanpu Zhou [aut]
Maintainer: Xuewei Cheng <xwcheng@hunnu.edu.cn>
Description: An implementation of popular screening methods that are commonly 
  employed in ultra-high and high dimensional data. Through this publicly 
  available package, we provide a unified framework to carry out model-free 
  screening procedures including 
  SIS (Fan and Lv (2008) <doi:10.1111/j.1467-9868.2008.00674.x>), 
  SIRS(Zhu et al. (2011)<doi:10.1198/jasa.2011.tm10563>), 
  DC-SIS (Li et al. (2012) <doi:10.1080/01621459.2012.695654>), 
  MDC-SIS(Shao and Zhang (2014) <doi:10.1080/01621459.2014.887012>), 
  Bcor-SIS (Pan et al. (2019) <doi:10.1080/01621459.2018.1462709>), 
  PC-Screen (Liu et al. (2020) <doi:10.1080/01621459.2020.1783274>), 
  WLS (Zhong et al.(2021) <doi:10.1080/01621459.2021.1918554>), 
  Kfilter (Mai and Zou (2015) <doi:10.1214/14-AOS1303>), 
  MVSIS (Cui et al. (2015) <doi:10.1080/01621459.2014.920256>), 
  PSIS (Pan et al. (2016) <doi:10.1080/01621459.2014.998760>), 
  CAS (Xie et al. (2020) <doi:10.1080/01621459.2019.1573734>), 
  CI-SIS (Cheng and Wang. (2023) <doi:10.1016/j.cmpb.2022.107269>), 
  CSIS (Cheng et al. (2024) <doi:10.1007/s00180-023-01399-5>) and Log-rank SIS.
License: GPL (>= 2)
SystemRequirements: Python (>= 3.8.0)
Encoding: UTF-8
Imports: survival, MASS, Ball, reticulate, stats, crayon, cli, dr,
        foreach, parallel, doParallel, fs
Suggests: knitr, utils, pkgdown
Language: en-US
NeedsCompilation: no
Repository: CRAN
RoxygenNote: 7.2.3
Packaged: 2026-05-13 17:54:22 UTC; cxw
Date/Publication: 2026-05-13 18:50:02 UTC
Built: R 4.5.2; ; 2026-05-13 19:41:45 UTC; unix
