% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/req_py.R
\name{req_py}
\alias{req_py}
\title{Detect Python Module}
\usage{
req_py()
}
\description{
A function to detect Python module.
}
\author{
Xuewei Cheng \email{xwcheng@hunnu.edu.cn}
}
